yakumo.neutron.v2.floating_ip

Package yakumo :: Package neutron :: Package v2 :: Module floating_ip |
[hide private]
[frames] | no frames]

# Module floating_ip

source code

Resource class and its manager for floating IPs in Networking V2 API

Classes | [hide private]
| Resource Resource class for floating IPs in Networking V2 API
| Manager Manager class for floating IPs in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('floating_network', 'floating_network_id', ma
      pper.Resource('neutron.network')), ('floating_ip', 'floating_ip_addres
      s', mapper.Noop), ('fixed_ip', 'fixed_ip_address', mapper.Noop), ('rou
      ter', 'router_id', mapper.Resource('neutron.router')), ('port', 'port_
      id', mapper.Resource('neutron.port')), ('project', 'tenant_id', mapper
      .Resource('project')),]